# Generated by Django 3.2.9 on 2021-11-23 12:32

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='MetaDeviceType',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False)),
                ('name', models.CharField(max_length=100)),
                ('vendor', models.CharField(max_length=50)),
                ('sha', models.CharField(max_length=40)),
                ('download_url', models.URLField()),
            ],
        ),
    ]
