# Generated by Django 3.2.9 on 2021-12-09 12:17

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('netbox_devicetype_importer', '0001_netbox_devicetype_importer'),
    ]

    operations = [
        migrations.AddField(
            model_name='metadevicetype',
            name='is_new',
            field=models.BooleanField(default=True),
        ),
        migrations.AlterField(
            model_name='metadevicetype',
            name='download_url',
            field=models.URLField(blank=True, null=True),
        ),
    ]
