# Generated by Django 3.2.9 on 2021-12-10 15:35

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('netbox_devicetype_importer', '0003_netbox_devicetype_importer'),
    ]

    operations = [
        migrations.AddField(
            model_name='metadevicetype',
            name='is_imported',
            field=models.BooleanField(default=False),
        ),
    ]
